function [lift_DWT_Image] = lift_DWT_1D(Org_Image,P0,U0)


//**********************************
// 1次元ウェーブレット変換
// 使い方：
//  [lift_DWT_Image] = lift_DWT_1D(Org_Image, P0, U0)
// 引数：
//  Org_Image : ウェーブレット変換するデータ(double型)
//  P0 : P0フィルタ係数
//  U0 : U0フィルタ係数
// 出力：
//  lift_DWT_Image : ウェーブレット変換後のデータ
//   　ウェーブレット変換後のデータは、[低域　高域]で並んでおります。
//**********************************
// 

//% 垂直方向のサブバンド分割
// 1次元の信号の対称拡張
// 左側の拡張　入力信号　右側の拡張
Xext = [Org_Image(:,3:-1:2),Org_Image(:,:),Org_Image(:,$-1:-1:$-2)];

//% 奇数成分フィルタリング（高域通過フィルタ）
X_d2 = Xext(:,1:2:$);
for i = 1:size(double(Xext),1)
  X_d2_P0(i,1:length(conv(X_d2(i,:),P0))) = conv(X_d2(i,:),P0);
end;
X_d2_P0_Q0 = round(X_d2_P0);

zX = [zeros(size(double(Xext),1),1),Xext(:,1:$)];
zX_d2 = zX(:,1:2:$);

Y_odd = -X_d2_P0_Q0+double(zX_d2);

//% 偶数成分フィルタリング（低域通過フィルタ）
for i = 1:size(mtlb_double(Xext),1)
  Y_odd_U0(i,1:length(conv(Y_odd(i,:),U0))) = conv(Y_odd(i,:),U0);
  Y_odd_U0_Q0(i,1:length(round(Y_odd_U0(i,:)))) = round(Y_odd_U0(i,:));
end;

Y_even = mtlb_a([zeros(size(mtlb_double(Xext),1),1),X_d2,zeros(size(mtlb_double(Xext),1),1)],Y_odd_U0_Q0);

//% 出力データの作成
Yl = Y_even(:,3:$-2);Yh = Y_odd(:,3:$-1);
lift_DWT_Image = [Yl,Yh];
endfunction
