function [Ext_Image] = lift_IDWT_1D(lift_DWT_Image,P0,U0)

//**********************************
// 1次元逆ウェーブレット変換
// 使い方：
//  [Ext_Image] = lift_IDWT_1D(lift_DWT_Image, P0, U0)
// 引数：
//  lift_DWT_Image : ウェーブレット変換されているデータ(double型)
//   　ウェーブレット変換されているデータは、[低域　高域]に並べる必要があります。
//  P0 : P0フィルタ係数
//  U0 : U0フィルタ係数
// 出力：
//  Ext_Image : ウェーブレット変換後のデータ
//**********************************
// 

//% LowとHighを分解
Yl = lift_DWT_Image(:,1:size(lift_DWT_Image,2)/2);
Yh = lift_DWT_Image(:,size(lift_DWT_Image,2)/2+1:$);

//% 対象拡張
Yext_l = [Yl(:,2),Yl(:,:),Yl(:,$)];
Yext_h = [Yh(:,1),Yh(:,:),Yh(:,$-1)];

//% 偶数成分
for i = 1:size(lift_DWT_Image,1)
  Yext_h_U0(i,:) = conv(Yext_h(i,:),U0);
  Yext_h_U0_Q0(i,:) = round(Yext_h_U0(i,:));
end;
X_even = [Yext_l zeros(size(lift_DWT_Image,1),1)] - Yext_h_U0_Q0;

//% 奇数成分
for i = 1:size(lift_DWT_Image,1)
  X_even_P0(i,:) = conv(X_even(i,:),P0);
  X_even_P0_Q0(i,:) = round(X_even_P0(i,:));
end;

X_odd = [zeros(size(lift_DWT_Image,1),1) Yext_h zeros(size(lift_DWT_Image,1),1)] + X_even_P0_Q0;

//% アップサンプリング及び、偶数成分と奇数成分との加算
// 逆ＷＴ画像の作成
Ext_Image = zeros(size(lift_DWT_Image,1), size(lift_DWT_Image,2));
Ext_Image(:,1:2:$) = X_even(:,2:$-2);
Ext_Image(:,2:2:$) = X_odd(:,3:$-2);
endfunction
