//**********************************************
//** Scliab演習7.2 (ウェーブレット変換逆変換) **
//**********************************************
// 使用法：
//         そのまま実行してください．
//**************************************
// 補足：
// 　本プログラムは，以下のプログラムを使用します．
//      lift_DWT_1D.sci
//      lift_DWT_2D.sci
//     lift_IDWT_1D.sci
//     lift_IDWT_2D.sci
// 　同一のフォルダに入れておいてください．
// 注意：
// 　画像は，n*2^3 x n*2^3(例えば,256x256)のサイズにして，
//   カラーにしてください．保存は，bmpとすること．
//   画像のサイズ変更などは，
//     http://www8.plala.or.jp/kusutaku/iview/
//   などのソフトウェアを使用してください．
//**************************************
// 
clear;

//**** 関数を読み込み *****
// wavelet_53.sceと同じフォルダにおいてください
exec('lift_DWT_1D.sci');
exec('lift_DWT_2D.sci');
exec('lift_IDWT_1D.sci');
exec('lift_IDWT_2D.sci');


P0 = [1,1]/2;// P0フィルタ
U0 = [1,1]/4;// U0フィルタ

// 画像の読み込みとdouble型への変換
Image = double(imread('lena.bmp'));
// 最終出力画像の生成のための初期化
Output_Image = zeros(size(Image,1),size(Image,2),size(Image,3));

// コンポーネントごとにウェーブレット変換を行う
// モノクロ：１コンポーネント
// カラー：３（RGB）コンポーネント
for i = 1:size(Image,3)
  Org_Image = Image(:,:,i);

  // 画像の表示(原画像)
  imshow(Org_Image);
  ImagesizeX = size(Org_Image,1);
  ImagesizeY = size(Org_Image,2);

  // 2次元のDWT (Level 1)
  DWT_Image = lift_DWT_2D(Org_Image,P0,U0);

  // 2次元のDWT (Level 2)
  // Level1で出力された画像の左上1/4のみを処理する
  DWT_Image_tmp = lift_DWT_2D(DWT_Image(1:ImagesizeX/2,1:ImagesizeY/2),P0,U0);
  // 処理後の画像を左上1/4にコピーする
  DWT_Image(1:ImagesizeX/2,1:ImagesizeY/2) = DWT_Image_tmp;

  // 2次元のDWT (Level 3)
  // Level1で出力された画像の左上1/16のみを処理する
  DWT_Image_tmp = lift_DWT_2D(DWT_Image(1:ImagesizeX/4,1:ImagesizeY/4),P0,U0);
  // 処理後の画像を左上1/16にコピーする
  DWT_Image(1:ImagesizeX/4,1:ImagesizeY/4) = DWT_Image_tmp;

  // 画像の表示(原画像)
  imshow(uint8(DWT_Image));

  // 2次元のIDWT (Level 3)
  DWT_Image_tmp = lift_IDWT_2D(DWT_Image(1:ImagesizeX/4,1:ImagesizeY/4),P0,U0);
  // 処理後の画像を左上1/16にコピーする
  DWT_Image(1:ImagesizeX/4,1:ImagesizeY/4) = DWT_Image_tmp;

  // 2次元のIDWT (Level 2)
  DWT_Image_tmp = lift_IDWT_2D(DWT_Image(1:ImagesizeX/2,1:ImagesizeY/2),P0,U0);
  // 処理後の画像を左上1/4にコピーする
  DWT_Image(1:ImagesizeX/2,1:ImagesizeY/2) = DWT_Image_tmp;

  // 2次元のIDWT (Level 1)
  Ext_Image = lift_IDWT_2D(DWT_Image,P0,U0);

  Output_Image(:,:,i) = double(Ext_Image);
  // imshow(uint8(Ext_Image));

  printf('%d コンポーネント 誤差の絶対値和 = %f\n',i, sum(abs(double(Image(:,:,i))-double(Output_Image(:,:,i)))));
end;


